@@ -1,12 +1,3 @@
-try:
-    import RPA.recognition as _unused
-
-    del _unused
-    HAS_RECOGNITION = True
-except ImportError:
-    HAS_RECOGNITION = False
-
-
 class ElementNotFound(ValueError):
     """No matching elements were found."""
 
@@ -30,9 +21,9 @@ class LibraryContext:
         return self.ctx.logger
 
     @property
-    def buffer(self):
-        return self.ctx.buffer
+    def active_pdf_document(self):
+        return self.ctx.active_pdf_document
 
-    @property
-    def rpa_pdf_document(self):
-        return self.ctx.rpa_pdf_document
+    @active_pdf_document.setter
+    def active_pdf_document(self, value):
+        self.ctx.active_pdf_document = value
